"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const theme_1 = require("../Styles/theme");
const Portal_1 = require("../Portal");
const utils_1 = require("../../utils");
const Icon_1 = __importDefault(require("../Icon"));
const ToastHost = props => {
    const { content, type, mask } = props;
    let icon = null;
    if (type === 'loading') {
        icon = react_1.default.createElement(react_native_1.ActivityIndicator, { animating: true, size: "large", color: "#fff", style: styles.icon });
    }
    else if (type === 'success') {
        icon = react_1.default.createElement(Icon_1.default, { name: "check", size: 32, color: "#fff" });
    }
    else if (type === 'fail') {
        icon = react_1.default.createElement(Icon_1.default, { name: "close-circle", size: 32, color: "#fff" });
    }
    return (react_1.default.createElement(react_native_1.View, { style: styles.container, pointerEvents: mask ? undefined : 'box-none' },
        react_1.default.createElement(react_native_1.View, { style: [styles.main, icon !== null ? styles.iconToast : styles.textToast] },
            icon,
            react_1.default.createElement(react_native_1.Text, { style: styles.text }, content))));
};
const styles = react_native_1.StyleSheet.create({
    container: {
        position: 'absolute',
        left: 0,
        top: 0,
        right: 0,
        bottom: 0,
        zIndex: theme_1.Theme.toastZIndex,
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
        backgroundColor: 'transparent',
    },
    main: {
        backgroundColor: theme_1.Theme.toastFill,
        minWidth: 100,
        alignItems: 'center',
    },
    iconToast: {
        borderRadius: theme_1.Theme.radiusLg,
        padding: theme_1.Theme.vSpacingLg,
    },
    textToast: {
        borderRadius: theme_1.Theme.radiusSm,
        paddingVertical: theme_1.Theme.vSpacingMd,
        paddingHorizontal: theme_1.Theme.vSpacingLg,
    },
    icon: {
        marginBottom: theme_1.Theme.vSpacingXs,
    },
    text: {
        color: theme_1.Theme.colorTextBaseInverse,
        fontSize: theme_1.Theme.fontSizeCaption,
    },
});
class Toast {
    static async show(type, content, duration = 3000, mask = true) {
        const key = Portal_1.portal.add(react_1.default.createElement(ToastHost, { type: type, content: content, mask: mask }));
        if (duration > 0) {
            await utils_1.sleep(duration);
            Portal_1.portal.remove(key);
        }
        return key;
    }
    /**
     *
     * @param content {string} 内容
     * @param mask {boolean} 是否显示蒙层
     * @returns
     */
    static loading(content, mask = true) {
        return this.show('loading', content, 0, mask);
    }
    /**
     *
     * @param key {number} Toast.loading的返回值
     */
    static hideLoading(key) {
        Portal_1.portal.remove(key);
    }
    /**
     *
     * @param content {string} 内容
     * @param duration {number} 展示时间，默认3000ms
     * @param mask {boolean} 是否显示蒙层
     */
    static success(content, duration = 3000, mask = false) {
        this.show('success', content, duration, mask);
    }
    /**
     *
     * @param content {string} 内容
     * @param duration {number} 展示时间，默认3000ms
     * @param mask {boolean} 是否显示蒙层
     */
    static fail(content, duration = 3000, mask = false) {
        this.show('fail', content, duration, mask);
    }
    /**
     *
     * @param content {string} 内容
     * @param duration {number} 展示时间，默认3000ms
     * @param mask {boolean} 是否显示蒙层
     */
    static info(content, duration = 3000, mask = false) {
        this.show('info', content, duration, mask);
    }
}
exports.default = Toast;
