import React, { useEffect, useState } from 'react';
import { DeviceEventEmitter, View, StyleSheet } from 'react-native';
const addEventKey = 'REACT_NATIVE_UI_VIEW_ADD_PORTAL';
const removeEventKey = 'REACT_NATIVE_UI_VIEW_REMOVE_PORTAL';
const eventEmitter = DeviceEventEmitter;
class PortalGuard {
    constructor() {
        this.key = 100;
    }
    add(elem) {
        const key = this.key++;
        eventEmitter.emit(addEventKey, { elem, key });
        return key;
    }
    remove(key) {
        eventEmitter.emit(removeEventKey, key);
    }
}
const PortalHost = () => {
    const [portalList, setPortalList] = useState([]);
    useEffect(() => {
        const listenerAdd = eventEmitter.addListener(addEventKey, mount);
        const listenerRemove = eventEmitter.addListener(removeEventKey, unmount);
        return () => {
            listenerAdd.remove();
            listenerRemove.remove();
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    const mount = (portalItem) => {
        setPortalList([...portalList, portalItem]);
    };
    const unmount = (key) => {
        setPortalList([...portalList].filter(item => item.key !== key));
    };
    return (React.createElement(React.Fragment, null, portalList.map(item => (React.createElement(View, { style: styles.portal, key: item.key, pointerEvents: "box-none" }, item.elem)))));
};
export const portal = new PortalGuard();
export default class Portal extends React.Component {
    render() {
        return (React.createElement(React.Fragment, null,
            this.props.children,
            React.createElement(PortalHost, null)));
    }
}
Portal.add = portal.add;
Portal.remove = portal.remove;
const styles = StyleSheet.create({
    portal: {
        position: 'absolute',
        left: 0,
        top: 0,
        right: 0,
        bottom: 0,
    },
});
